--
-- task relation dao.find task collection of records by term.
--
SELECT DISTINCT
    R.FULL_DATE
   ,T.ID AS TASK_ID
   ,T.TITLE
   ,B.BODY
   ,T.START_DATE
   ,T.START_YEAR
   ,T.START_MONTH
   ,T.START_DAY_OF_MONTH
   ,T.DEAD_LINE
   ,T.DEAD_LINE_YEAR
   ,T.DEAD_LINE_MONTH
   ,T.DEAD_LINE_DAY_OF_MONTH
   ,T.PRIORITY_ORDER
   ,R.ACTIVITY_ID      AS ACTIVITY_ID
   ,V.NAME             AS ACTIVITY_VALUE
   ,R.STATUS_ID
   ,R.CLASSIFICATION_ID
   ,C.TYPE             AS CLASSIFICATION_TYPE
   ,C.VALUE            AS CLASSIFICATION_VALUE
   ,O.COLOR            AS COLOR_VALUE
   ,R.PERSON_IN_CHARGE_ID
   ,COALESCE(U1.LAST_NAME,'')  AS PERSON_LAST_NAME
   ,COALESCE(U1.FIRST_NAME,'') AS PERSON_FIRST_NAME
   ,T.REGISTERED
   ,H2.MODIFIED
FROM
   (SELECT TC.*
    FROM task_collection_of_records TC
    WHERE
        TC.collect_type = /*collectType*/'1'
    AND TC.full_date BETWEEN /*startDate*/'20080518' AND /*endDate*/'20080524'
    AND TC.person_in_charge_id = /*userId*/1
   ) R 
    INNER JOIN tasks                   T  ON R.TASK_ID           = T.ID
    INNER JOIN task_bodies             B  ON R.TASK_ID           = B.TASK_ID
    INNER JOIN (
        SELECT
            H1.task_id
           ,MAX(H1.registered) as MODIFIED
        FROM
            task_histories H1
        GROUP BY
            H1.task_id
    ) H2 ON R.TASK_ID = H2.TASK_ID
    INNER JOIN activities              V  ON R.ACTIVITY_ID         = V.ID
    INNER JOIN activity_members        Y  ON V.ID                  = Y.ACTIVITY_ID
                                         AND Y.USER_ID             = /*userId*/1
    INNER JOIN classifications         C  ON R.CLASSIFICATION_ID   = C.ID
    INNER JOIN activity_relations      I  ON R.ACTIVITY_ID         = I.ACTIVITY_ID
                                         AND I.USER_ID             = /*userId*/1
    INNER JOIN activity_colors         O  ON I.COLOR_ID            = O.ID
    LEFT  JOIN users                   U1 ON R.PERSON_IN_CHARGE_ID = U1.ID
ORDER BY
    R.FULL_DATE
   ,R.CLASSIFICATION_ID
   ,R.STATUS_ID
   ,T.DEAD_LINE
   ,R.ACTIVITY_ID
   ,T.ID